/* eslint-disable no-const-assign */
import axios from 'axios'
// import router from '../../src/router/index'
import { Notify } from '@nutui/nutui'
// 构建axios实例
axios.create({
  baseURL: process.env.BASE_API,
  timeout: 10000
})
axios.interceptors.request.use(config => {
  const token = sessionStorage.getItem('token')
  if (token) {
    config.headers.Authorization = 'Bearer ' + token
  }
  return config
},
err => {
  return Promise.reject(err)
})
axios.interceptors.response.use(
  response => {
    if (response.data.errcode !== 0 || response.data.errcode === 403) {
      if (response.data.errmsg.cmd) {
        Notify.warn(response.data.errmsg.cmd)
        return false
      }
      Notify.warn(response.data.errmsg)
      return false
    }
    return response.data
  },
  error => {
    const { status, data } = error.response
    if (status === 401) {
      Notify.warn('请重新登录')
      // router.push('/login')
      return false
    }
    if (status === 500) {
      if (data.cmd) {
        Notify.warn(data.cmd)
        return false
      }
      if (data.errmsg) {
        Notify.warn(data.errmsg)
        return false
      }
    }
    Notify.warn(data.message || data.errmsg)
    return data
  }
)
export default axios
